// Copyright (c) 2021 Terminus, Inc.
//
// This program is free software: you can use, redistribute, and/or modify
// it under the terms of the GNU Affero General Public License, version 3
// or later ("AGPL"), as published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.

package apistructs

import "strconv"

// 自定义字段详情
type IssuePropertyInstance struct {
	IssuePropertyIndex
	ArbitraryValue   interface{}         `json:"arbitraryValue"` // 自定义的值
	EnumeratedValues []PropertyEnumerate `json:"enumeratedValues"`
	Values           []int64             `json:"values"`
}

func (i IssuePropertyInstance) GetArb() string {
	switch i.ArbitraryValue.(type) {
	case float64:
		return strconv.FormatInt(int64(i.ArbitraryValue.(float64)), 10)
	case string:
		return i.ArbitraryValue.(string)
	default:
		return ""
	}
}

type PropertyEnumerate struct {
	Name string `json:"name"`
	ID   int64  `json:"id"`
}

type IssueAndPropertyAndValue struct {
	IssueID  int64                        `json:"issueID"`
	Property []IssuePropertyExtraProperty `json:"property"`
}

// 用于自定义字段实例操作
type IssuePropertyExtraProperty struct {
	PropertyID       int64        `json:"propertyID"`
	PropertyType     PropertyType `json:"propertyType"`
	PropertyName     string       `json:"propertyName"`
	Required         bool         `json:"required"`
	DisplayName      string       `json:"displayName"`
	ArbitraryValue   interface{}  `json:"arbitraryValue"`
	EnumeratedValues []Enumerate  `json:"enumeratedValues"`
	Values           []int64      `json:"values"`
}

// 创建事件的自定义字段请求
type IssuePropertyRelationCreateRequest struct {
	OrgID     int64                   `json:"orgID"`
	ProjectID int64                   `json:"projectID"`
	IssueID   int64                   `json:"issueID"`  // 事件ID
	Property  []IssuePropertyInstance `json:"property"` // 自定义字段
	IdentityInfo
}

// 更新事件的自定义字段请求
type IssuePropertyRelationUpdateRequest struct {
	OrgID     int64 `json:"orgID"`
	ProjectID int64 `json:"projectID"`
	IssueID   int64 `json:"issueID"`
	IssuePropertyExtraProperty
	IdentityInfo
}

func (i IssuePropertyRelationUpdateRequest) GetArb() string {
	switch i.ArbitraryValue.(type) {
	case float64:
		return strconv.FormatInt(int64(i.ArbitraryValue.(float64)), 10)
	case string:
		return i.ArbitraryValue.(string)
	default:
		return ""
	}
}

// 查询事件的自定义字段请求
type IssuePropertyRelationGetRequest struct {
	OrgID             int64             `json:"orgID"`
	IssueID           int64             `json:"issueID"`           // 事件ID
	PropertyIssueType PropertyIssueType `json:"propertyIssueType"` // 任务类型
	IdentityInfo
}

// 查询事件的自定义字段响应
type IssuePropertyRelationGetResponse struct {
	Header
	IssueAndPropertyAndValue
}
